<?php
namespace Dominie\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Dominie.
* @since 1.0.0
**/
class Dmne_Section_Title extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'dmne-section-title';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Dmne Section Title', 'dominie' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return ' eicon-post-title';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'dominie_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'dominie' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'dominie' ),
			]
		);

		$this->add_control(
			'sub-title',
			[
				'label' => esc_html__( 'Sub Title', 'dominie' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Add sub title here', 'dominie' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'dominie' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( 'Add Your Title Here', 'dominie' ),
			]
		);
		$this->add_control(
			'content',
			[
				'label' => esc_html__( 'Content', 'dominie' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( 'Add Your Content Here', 'dominie' ),
			]
		);
		$this->add_control(
			'content-2',
			[
				'label' => esc_html__( 'Content 2', 'dominie' ),
				'type' => Controls_Manager::TEXTAREA,
			]
		);
		$this->add_control(
			'btn-text',
			[
				'label' => esc_html__( 'Btn Text', 'dominie' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'View All Courses', 'dominie' ),
			]
		);
		$this->add_control(
			'btn-url',
			[
				'label' => esc_html__( 'Btn URL', 'dominie' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '#', 'dominie' ),
			]
		);
		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'dominie' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'dominie' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'dominie' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'dominie' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'dominie' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}}' => 'text-align: {{VALUE}};',
				],
			]
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'dominie' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		//color field
		$this->add_responsive_control(
			'bottom_space',
			[
				'label' => __( 'Bottom Spacing', 'forgood' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .section-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					'(mobile){{WRAPPER}} .section-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'sub-title_color',
			[
				'label' => __( 'Sub Title Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .sub-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title-color',
			[
				'label' => __( 'Title Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content-color',
			[
				'label' => __( 'Content Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'btn_color',
			[
				'label' => __( 'Btn Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .section-title .btn' => 'background: {{VALUE}};',
				],
			]
		);


		$this->add_control(
			'text_transform',
			[
				'label' => esc_html__( 'Text Transform', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'None', 'dominie' ),
					'uppercase' => esc_html__( 'UPPERCASE', 'dominie' ),
					'lowercase' => esc_html__( 'lowercase', 'dominie' ),
					'capitalize' => esc_html__( 'Capitalize', 'dominie' ),
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display(); ?>

        <div class="section-title">
        	<?php if (!empty($settings['sub-title'])) { ?>
        		<h5 class="sub-title"><?php echo esc_html( $settings['sub-title']  ); ?></h5>
        	<?php } ?>
        	<?php if (!empty($settings['title'])) { ?>
        		<h2 class="title"><?php echo esc_html( $settings['title']  ); ?></h2>
        	<?php } ?>
        	<?php if (!empty($settings['content'])) { ?>
        		<p><?php echo esc_html( $settings['content']  ); ?></p>
        	<?php } ?>
        	<?php if (!empty($settings['content-2'])) { ?>
        		<p><?php echo esc_html( $settings['content-2']  ); ?></p>
        	<?php } ?>
        	<?php if (!empty($settings['btn-text'])) { ?>
        		<a class="btn btn-base" href="<?php echo esc_url( $settings['btn-url']  ); ?>"><?php echo esc_html( $settings['btn-text']  ); ?></a>
        	<?php } ?>
        	
        </div>
	<?php }
}
